Index: /trunk/MagicSoft/Mars/Changelog
===================================================================
--- /trunk/MagicSoft/Mars/Changelog	(revision 6724)
+++ /trunk/MagicSoft/Mars/Changelog	(revision 6725)
@@ -34,4 +34,7 @@
      - re-added MFEventSelector which had been removed by TB on the
        15.2.2005.
+   
+   * mjobs/MJCalib.[h,cc]
+     - added flag fPulsePosCheck
 
  2005/03/02 Markus Gaug
Index: /trunk/MagicSoft/Mars/mjobs/MJCalib.cc
===================================================================
--- /trunk/MagicSoft/Mars/mjobs/MJCalib.cc	(revision 6724)
+++ /trunk/MagicSoft/Mars/mjobs/MJCalib.cc	(revision 6725)
@@ -43,10 +43,13 @@
 //
 // Sets:
 // - fDataFlag     to kIsUseRootData
 // - fRuns         to NULL
 // - fCheckedPixId to fgCheckedPixId
 // - fPixelCheck   to kFALSE
 //
-MJCalib::MJCalib() : fDataFlag(kIsUseRootData), fStorage(0), fPixelCheck(kFALSE), fRuns(NULL)
+MJCalib::MJCalib() : fDataFlag(kIsUseRootData), fStorage(0), 
+                     fPixelCheck(kFALSE), fPulsePosCheck(kFALSE),
+                     fRuns(NULL)
 {
   SetCheckedPixId();
@@ -57,4 +60,7 @@
     if (HasEnv("PixelCheck"))
         SetPixelCheck(GetEnv("PixelCheck", fPixelCheck));
+
+    if (HasEnv("PulsePosCheck"))
+        SetPulsePosCheck(GetEnv("PulsePosCheck", fPulsePosCheck));
 
     if (HasEnv("CheckedPixId"))
@@ -43,10 +43,13 @@
 //
 // Sets:
-// - fDataFlag     to kIsUseRootData
-// - fRuns         to NULL
-// - fCheckedPixId to fgCheckedPixId
-// - fPixelCheck   to kFALSE
+// - fDataFlag      to kIsUseRootData
+// - fRuns          to NULL
+// - fCheckedPixId  to fgCheckedPixId
+// - fPixelCheck    to kFALSE
+// - fPulsePosCheck to kFALSE
 //
Index: /trunk/MagicSoft/Mars/mjobs/MJCalib.h
===================================================================
--- /trunk/MagicSoft/Mars/mjobs/MJCalib.h	(revision 6724)
+++ /trunk/MagicSoft/Mars/mjobs/MJCalib.h	(revision 6725)
@@ -22,20 +22,22 @@
     static const Int_t fgCheckedPixId;  //! Default for fCheckedPixId
 
-    Byte_t fDataFlag;                    // Bit-field to store the data type
+    Byte_t fDataFlag;                   // Bit-field to store the data type
 
-    enum  Storage_t                        // Possible devices for calibration
+    enum  Storage_t                     // Possible devices for calibration
       {
         kNoStorage,
         kHistsStorage
-      };                                  // Possible flags for the storage of results
+      };                                // Possible flags for the storage of results
     
-    Byte_t fStorage;                      // Bit-field for chosen storage type
+    Byte_t fStorage;                    // Bit-field for chosen storage type
 
 protected:
 
-    Bool_t fPixelCheck;                  // Check a test pixel?
-    Int_t  fCheckedPixId;                // ID of checked pixel
+    Bool_t fPixelCheck;                 // Check a test pixel?
+    Int_t  fCheckedPixId;               // ID of checked pixel
 
-    MRunIter *fRuns;                     // Data files, only used for test applications, default is sequence files!
+    Bool_t fPulsePosCheck;              // Check pulse position?
+    
+    MRunIter *fRuns;                    // Data files, only used for test applications, default is sequence files!
 
     Bool_t CheckEnvLocal();
@@ -61,6 +63,7 @@
     void SetDataType(DataType_t type) { fDataFlag=type; }
   
-    void SetPixelCheck  ( const Bool_t b=kTRUE )         { fPixelCheck   = b; }
-    void SetCheckedPixId( const Int_t i=fgCheckedPixId ) { fCheckedPixId = i; }
+    void SetPixelCheck   ( const Bool_t b=kTRUE )          { fPixelCheck    = b; }
+    void SetPulsePosCheck( const Bool_t b=kTRUE )          { fPulsePosCheck = b; }
+    void SetCheckedPixId ( const Int_t  i=fgCheckedPixId ) { fCheckedPixId  = i; }
 
     void SetNoStorage    ( const Bool_t b=kTRUE ) { b ? SETBIT(fStorage,kNoStorage)    : CLRBIT(fStorage,kNoStorage); }
